# PROCESSADOR DE IMAGENS EM PORTUGUES - BRASIL

Pacote de processamento de imagens desenvolvido com base na biblioteca scikit-image com comandos em portugues do Brasil.

O pacote processador_de_imagem_ptbr e usado para:

	Processamento:
		-  Encontrar taxa de similaridade entre as imagens
		-  Realizar correspondencia de histograma
		-  Redimensionar imagem

	Utilidades:
		-  Ler imagem
		-  Salvar imagem
		-  Plotar imagem
		-  Mostrar resultado de combinacao das imagens
		-  Plotar histograma

## Instalacao

Usar o gerenciador de pacotes [pip](https://pip.pypa.io/en/stable/) para instalar o processador_de_imagens

```bash
pip install processador_de_imagem_ptbr
```

## Autor
Gabriel Calasans

## License
[MIT](https://choosealicense.com/licenses/mit/)